@@ -179,6 +179,8 @@ struct _ClutterActor
  *   sub-classes to advertise whether they need an offscreen redirect
  *   to get the correct opacity. See
  *   clutter_actor_set_offscreen_redirect() for details.
+ * @paint_node: virtual function for creating paint nodes and attaching
+ *   them to the render tree
  *
  * Base class for actors.
  */
@@ -253,14 +255,17 @@ struct _ClutterActorClass
   /* accessibility support */
   AtkObject * (* get_accessible)    (ClutterActor         *self);
 
-  gboolean    (* get_paint_volume)  (ClutterActor         *actor,
+  gboolean (* get_paint_volume)     (ClutterActor         *actor,
                                      ClutterPaintVolume   *volume);
 
   gboolean (* has_overlaps)         (ClutterActor         *self);
 
+  void     (* paint_node)           (ClutterActor         *self,
+                                     ClutterPaintNode     *root);
+
   /*< private >*/
   /* padding for future expansion */
-  gpointer _padding_dummy[28];
+  gpointer _padding_dummy[27];
 };
 
 /**
@@ -464,6 +469,29 @@ gboolean                        clutter_actor_is_in_clone_paint
 gboolean                        clutter_actor_get_paint_box                     (ClutterActor               *self,
                                                                                  ClutterActorBox            *box);
 gboolean                        clutter_actor_has_overlaps                      (ClutterActor               *self);
+
+/* Content */
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_set_content                       (ClutterActor               *self,
+                                                                                 ClutterContent             *content);
+CLUTTER_AVAILABLE_IN_1_10
+ClutterContent *                clutter_actor_get_content                       (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_set_content_gravity               (ClutterActor               *self,
+                                                                                 ClutterContentGravity       gravity);
+CLUTTER_AVAILABLE_IN_1_10
+ClutterContentGravity           clutter_actor_get_content_gravity               (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_set_content_scaling_filters       (ClutterActor               *self,
+                                                                                 ClutterScalingFilter        min_filter,
+                                                                                 ClutterScalingFilter        mag_filter);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_get_content_scaling_filters       (ClutterActor               *self,
+                                                                                 ClutterScalingFilter       *min_filter,
+                                                                                 ClutterScalingFilter       *mag_filter);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_get_content_box                   (ClutterActor               *self,
+                                                                                 ClutterActorBox            *box);
 CLUTTER_AVAILABLE_IN_1_10
 void                            clutter_actor_set_background_color              (ClutterActor               *self,
                                                                                  const ClutterColor         *color);
@@ -642,6 +670,39 @@ void                            clutter_actor_apply_relative_transform_to_point
 void                            clutter_actor_get_transformation_matrix         (ClutterActor               *self,
                                                                                  CoglMatrix                 *matrix);
 
+/* Implicit animations */
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_save_easing_state                 (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_restore_easing_state              (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_set_easing_mode                   (ClutterActor               *self,
+                                                                                 ClutterAnimationMode        mode);
+CLUTTER_AVAILABLE_IN_1_10
+ClutterAnimationMode            clutter_actor_get_easing_mode                   (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_set_easing_duration               (ClutterActor               *self,
+                                                                                 guint                       msecs);
+CLUTTER_AVAILABLE_IN_1_10
+guint                           clutter_actor_get_easing_duration               (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_set_easing_delay                  (ClutterActor               *self,
+                                                                                 guint                       msecs);
+CLUTTER_AVAILABLE_IN_1_10
+guint                           clutter_actor_get_easing_delay                  (ClutterActor               *self);
+CLUTTER_AVAILABLE_IN_1_10
+ClutterTransition *             clutter_actor_get_transition                    (ClutterActor               *self,
+                                                                                 const char                 *name);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_add_transition                    (ClutterActor               *self,
+                                                                                 const char                 *name,
+                                                                                 ClutterTransition          *transition);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_remove_transition                 (ClutterActor               *self,
+                                                                                 const char                 *name);
+CLUTTER_AVAILABLE_IN_1_10
+void                            clutter_actor_remove_all_transitions            (ClutterActor               *self);
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ACTOR_H__ */
