@@ -81,7 +81,7 @@ _clutter_paint_node_init_types (void)
                                         COGL_TEXTURE_TYPE_2D);
   cogl_pipeline_set_color (default_texture_pipeline, &cogl_color);
   cogl_pipeline_set_layer_wrap_mode (default_texture_pipeline, 0,
-                                     COGL_PIPELINE_WRAP_MODE_AUTOMATIC);
+                                     COGL_PIPELINE_WRAP_MODE_CLAMP_TO_EDGE);
 }
 
 /*
@@ -104,6 +104,7 @@ struct _ClutterRootNode
 
   CoglBufferBit clear_flags;
   CoglColor clear_color;
+  CoglMatrix modelview;
 };
 
 G_DEFINE_TYPE (ClutterRootNode, clutter_root_node, CLUTTER_TYPE_PAINT_NODE)
@@ -113,6 +114,11 @@ clutter_root_node_pre_draw (ClutterPaintNode *node)
 {
   ClutterRootNode *rnode = (ClutterRootNode *) node;
 
+  cogl_push_matrix ();
+
+  cogl_framebuffer_set_modelview_matrix (rnode->framebuffer,
+                                         &rnode->modelview);
+
   cogl_framebuffer_clear (rnode->framebuffer,
                           rnode->clear_flags,
                           &rnode->clear_color);
@@ -123,6 +129,7 @@ clutter_root_node_pre_draw (ClutterPaintNode *node)
 static void
 clutter_root_node_post_draw (ClutterPaintNode *node)
 {
+  cogl_pop_matrix ();
 }
 
 static void
@@ -148,12 +155,14 @@ clutter_root_node_class_init (ClutterRootNodeClass *klass)
 static void
 clutter_root_node_init (ClutterRootNode *self)
 {
+  cogl_matrix_init_identity (&self->modelview);
 }
 
 ClutterPaintNode *
 _clutter_root_node_new (CoglFramebuffer    *framebuffer,
                         const ClutterColor *clear_color,
-                        CoglBufferBit       clear_flags)
+                        CoglBufferBit       clear_flags,
+                        const CoglMatrix   *matrix)
 {
   ClutterRootNode *res;
 
@@ -166,12 +175,9 @@ _clutter_root_node_new (CoglFramebuffer    *framebuffer,
                             clear_color->alpha);
   cogl_color_premultiply (&res->clear_color);
 
-  if (G_LIKELY (framebuffer != NULL))
-    res->framebuffer = cogl_object_ref (framebuffer);
-  else
-    res->framebuffer = cogl_object_ref (cogl_get_draw_framebuffer ());
-
+  res->framebuffer = cogl_object_ref (framebuffer);
   res->clear_flags = clear_flags;
+  res->modelview = *matrix;
 
   return (ClutterPaintNode *) res;
 }
@@ -333,14 +339,6 @@ struct _ClutterPipelineNode
   CoglPipeline *pipeline;
 };
 
-/**
- * ClutterPipelineNodeClass:
- *
- * The <structname>ClutterPipelineNodeClass</structname> structure is an opaque
- * type whose members cannot be directly accessed.
- *
- * Since: 1.10
- */
 struct _ClutterPipelineNodeClass
 {
   ClutterPaintNodeClass parent_class;
@@ -522,13 +520,21 @@ clutter_pipeline_node_new (CoglPipeline *pipeline)
  * Color node
  */
 
+/**
+ * ClutterColorNode:
+ *
+ * The <structname>ClutterColorNode</structname> structure is an opaque
+ * type whose members cannot be directly accessed.
+ *
+ * Since: 1.10
+ */
 struct _ClutterColorNode
 {
   ClutterPipelineNode parent_instance;
 };
 
 /**
- * ClutterColorNodeClass:
+ * ClutterColorNode:
  *
  * The <structname>ClutterColorNodeClass</structname> structure is an
  * opaque type whose members cannot be directly accessed.
@@ -597,13 +603,21 @@ clutter_color_node_new (const ClutterColor *color)
  * Texture node
  */
 
+/**
+ * ClutterTextureNode:
+ *
+ * The <structname>ClutterTextureNode</structname> structure is an opaque
+ * type whose members cannot be directly accessed.
+ *
+ * Since: 1.10
+ */
 struct _ClutterTextureNode
 {
   ClutterPipelineNode parent_instance;
 };
 
 /**
- * ClutterTextureNodeClass:
+ * ClutterTextureNode:
  *
  * The <structname>ClutterTextureNodeClass</structname> structure is an
  * opaque type whose members cannot be directly accessed.
@@ -709,14 +723,6 @@ struct _ClutterTextNode
   CoglColor color;
 };
 
-/**
- * ClutterTextNodeClass:
- *
- * The <structname>ClutterTextNodeClass</structname> structure is an opaque
- * type whose contents cannot be directly accessed.
- *
- * Since: 1.10
- */
 struct _ClutterTextNodeClass
 {
   ClutterPaintNodeClass parent_class;
@@ -909,14 +915,6 @@ struct _ClutterClipNode
   ClutterPaintNode parent_instance;
 };
 
-/**
- * ClutterClipNodeClass:
- *
- * The <structname>ClutterClipNodeClass</structname> structure is an opaque
- * type whose members cannot be directly accessed.
- *
- * Since: 1.10
- */
 struct _ClutterClipNodeClass
 {
   ClutterPaintNodeClass parent_class;
