@@ -108,7 +108,6 @@ typedef struct _DimensionData {
   gfloat final_size;
 
   guint expand  : 1;
-  guint shrink  : 1;
   guint visible : 1;
 } DimensionData;
 
@@ -822,7 +821,6 @@ calculate_col_widths (ClutterTableLayout *self,
        child = clutter_actor_get_next_sibling (child))
     {
       ClutterTableChild *meta;
-      DimensionData *col;
       gfloat c_min, c_pref;
       gfloat min_width, pref_width;
       gint start_col, end_col;
@@ -839,7 +837,6 @@ calculate_col_widths (ClutterTableLayout *self,
       if (meta->col_span < 2)
         continue;
 
-      col = &columns[meta->col];
       start_col = meta->col;
       end_col = meta->col + meta->col_span - 1;
 
@@ -857,11 +854,14 @@ calculate_col_widths (ClutterTableLayout *self,
           if (columns[i].expand)
             n_expand++;
 
-          if (!col->visible)
+          if (!columns[i].visible)
             {
-              col->visible = TRUE;
+              columns[i].visible = TRUE;
               priv->visible_cols += 1;
             }
+
+          if (!columns[i].expand)
+            columns[i].expand = meta->x_fill;
         }
       min_width += priv->col_spacing * (meta->col_span - 1);
       pref_width += priv->col_spacing * (meta->col_span - 1);
@@ -1001,12 +1001,8 @@ calculate_col_widths (ClutterTableLayout *self,
             {
               if (columns[i].expand)
                 {
-                  if (n_expand)
-                    columns[i].final_size = columns[i].pref_size
-                                          + (extra_width / n_expand);
-                  else
-                    columns[i].final_size = columns[i].pref_size
-                                          + (extra_width / priv->n_cols);
+                  columns[i].final_size = columns[i].pref_size
+                                        + (extra_width / n_expand);
                 }
               else
                 columns[i].final_size = columns[i].pref_size;
@@ -1137,6 +1133,9 @@ calculate_row_heights (ClutterTableLayout *self,
               rows[i].visible = TRUE;
               priv->visible_rows += 1;
             }
+
+          if (!rows[i].expand)
+            rows[i].expand = meta->y_fill;
         }
 
       min_height += priv->row_spacing * (meta->row_span - 1);
@@ -1286,12 +1285,8 @@ calculate_row_heights (ClutterTableLayout *self,
             {
               if (rows[i].expand)
                 {
-                  if (n_expand)
-                    rows[i].final_size = rows[i].pref_size
-                                       + (extra_height / n_expand);
-                  else
-                    rows[i].final_size = rows[i].pref_size
-                                       + (extra_height / priv->n_rows);
+                  rows[i].final_size = rows[i].pref_size
+                                     + (extra_height / n_expand);
                 }
               else
                 rows[i].final_size = rows[i].pref_size;
