@@ -51,7 +51,7 @@ typedef struct _ClutterWaylandSurfacePrivate ClutterWaylandSurfacePrivate;
  *
  * The #ClutterWaylandSurface structure contains only private data
  *
- * Since: 1.8
+ * Since: 1.10
  * Stability: unstable
  */
 struct _ClutterWaylandSurface
@@ -64,21 +64,36 @@ struct _ClutterWaylandSurface
 
 /**
  * ClutterWaylandSurfaceClass:
+ * @queue_damage_redraw: class handler of the #ClutterWaylandSurface::queue-damage-redraw signal
  *
  * The #ClutterWaylandSurfaceClass structure contains only private data
  *
- * Since: 0.8
+ * Since: 1.10
  * Stability: unstable
  */
 struct _ClutterWaylandSurfaceClass
 {
   /*< private >*/
   ClutterActorClass parent_class;
+
+  /*< public >*/
+  void (*queue_damage_redraw) (ClutterWaylandSurface *texture,
+                               gint x,
+                               gint y,
+                               gint width,
+                               gint height);
+
+  /*< private >*/
+  /* padding for future expansion */
+  gpointer _padding_dummy[8];
 };
 
 GType clutter_wayland_surface_get_type (void) G_GNUC_CONST;
 
 ClutterActor *clutter_wayland_surface_new               (struct wl_surface *surface);
+void          clutter_wayland_surface_set_surface       (ClutterWaylandSurface *self,
+                                                         struct wl_surface *surface);
+struct wl_surface *clutter_wayland_surface_get_surface  (ClutterWaylandSurface *self);
 gboolean      clutter_wayland_surface_attach_buffer     (ClutterWaylandSurface *self,
                                                          struct wl_buffer *buffer,
                                                          GError **error);
@@ -88,6 +103,7 @@ void          clutter_wayland_surface_damage_buffer     (ClutterWaylandSurface *
                                                          gint32 y,
                                                          gint32 width,
                                                          gint32 height);
+CoglTexture  *clutter_wayland_surface_get_cogl_texture  (ClutterWaylandSurface *self);
 
 G_END_DECLS
 
